==> pgmarket-1.5.2.tar.gz: pgmarket-1.5.2/locale/us/global-admin.inc.php <==
<?php

/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
/* (c) 2000 Fabio Molinari <fabio.m@mclink.it> */
/* (c) 2001 Andrew Stubbs <andrews@stusoft.com> */

$t->set_var(array(

"Insufficient_Privileges" => "Insufficient Privileges",
"Administration" => "Administration",
"admin_footer_message" => "$CFG->myname" . " \"<i>Electronic Store - Commercio elettronico</i>\"",
"Save_Changes" => "Save Changes",
"Import_Button_Label" => "Import",
"Add_Subcategory" => "Add Subcategory",
"Products_Management" => "Products Management",
"Add_Product" => "Add Product",
"P_Add_Product" => "[+P] Add Product",
"Import_Products" => "Import products",
"Import_Images" => "Import Images",
"Delete_Product" => "Delete Product",
"Edit_Product" => "Edit Product",
"Edit_this_product" => "Edit this product",
"Special_Level" => "Special Level",
"Special_Flag" => "Special Product",
"Delete_Current_Image" => "Delete Current Image (leave the product without any image)",
"Import_Images_Button_Label" => "Import Images",
"Brands_Management" => "Brands Management",
"B_Add_Brand" => "[+B] Add Brand",
"Import_Brands" => "Import Brands",
"Edit_this_brand" => "Edit this brand",
"Brand_reset_for_products" => "The Brand has been reset for all products of that brand",
"Add_Brand" => "Add Brand",
"Categories_Management" => "Categories Management",
"C_Add_Category" => "[+C] Add Category",
"Import_Categories" => "Import categories",
"Edit_this_category" => "Edit this category",
"Add_a_subcategory_under" => "Add a subcategory under",
"All_the_products_and_sub_categories_belonging_to" => "All the products and sub-categories belonging to",
"have_been_reassigned_to_male_plural" => "have been reassigned to",
"IVA_Management" => $IVA . " Management",
"I_Add_IVA" => "[+I] Add " . $IVA . " percentage",
"Import_IVA" => "Import " . $IVA . " percentages",
"Edit_this_IVA" => "Edit this " . $IVA . " percentage",
"Add_IVA" => "Add " . $IVA,
"The_IVA_Percentage" => "The ". $IVA . " percentage",
"IVA_reset_for_products" => "The " . $IVA . " percentage has been reset for all products with that " . $IVA . " percentage",
"Cust_Info" => "Cust. Info",
"Orders_States_Management" => "Orders States Management",
"Delete_this_order" => "Delete this order",
"Edit_this_order" => "Edit this order",
"S_Add_Order_State" => "[+S] Add Order State",
"Import_Orders_States" => "Import Orders States",
"Edit_this_order_state" => "Edit this order state",
"Add_Order_State" => "Add Order State",
"The_Order_State" => "The Order State",
"The_order_state" => "The order state",
"Order_State_reset_for_orders" => "The Order State has been reset for all orders in the named state",
"Add_a_product_under" => "Add a product under",
"currently_its_name_is_male_singular" => "currently its name is",
"currently_its_name_is_female_singular" => "currently its name is",
"currently_its_value_is_female_singular" => "currently its value is",
"Users_Management" => "Users Management",
"Users" => "Users",
"USERS" => "USERS",
"U_Add_User" => "[+U] Add User",
"U_Add_Company_User" => "[+U] Add Company User",
"U_Import_Users" => "Import users",
"Data_handl" => "Data handl.",
"Advert" => "Advert.",
"Reset_password_for" => "Reset password for",
"Change_password_for" => "Change password for",
"Edit_this_user" => "Edit this user",
"Email_this_user" => "Email this user",
"Add_User" => "Add User",
"The_user" => "The user",
"data_have_been_updated" => "data have been updated",
"Privilege" => "Privilege",
"Auth_data_handling_az" => "Auth. data h.",
"Auth_data_handling_pf" => "Auth. pers. data h.",
"Accept_advert_material" => "Accept. advert. mat.",
"Authorization_for_data_handling_az" => "Authorization for data handling",
"Authorization_for_data_handling_pf" => "Authorization for personal data handling",
"Acceptance_of_advertising_material" => "Acceptance of advertising material",
"Our_Notes" => "Our Notes",
"Registration_Date" => "Reg. Date",
"_Import_File" => "File to be Imported",
"End_Import" => "Import Completed.",

));

?>

==> pgmarket-1.5.3.tar.gz: pgmarket-1.5.3/locale/us/global-admin.inc.php <==
<?php

/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
/* (c) 2000 Fabio Molinari <fabio.m@mclink.it> */
/* (c) 2001 Andrew Stubbs <andrews@stusoft.com> */

$t->set_var(array(

"Insufficient_Privileges" => "Insufficient Privileges",
"Administration" => "Administration",
"admin_footer_message" => "$CFG->myname" . " \"<i>Electronic Store - Commercio elettronico</i>\"",
"Languages" => "Languages",
"Add_Lang" => "Add Language",
"L_Add_Lang" => "[+L] Add Language",
"Language" => "Language",
"The_language" => "The language",
"Choose" => "Choose",
"Selected_Internationalization_Language" => "Selected Internationalization Language",
"Internationalization" => "Internazionalizzazione",
"internationalization_deleted" => "internationalization deleted",
"Save_Changes" => "Save Changes",
"Import_Button_Label" => "Import",
"Add_Subcategory" => "Add Subcategory",
"Products_Management" => "Products Management",
"Products_Management_i18n" => "Products Management - I18N",
"Add_Product" => "Add Product",
"P_Add_Product" => "[+P] Add Product",
"Import_Products" => "Import products",
"Import_Images" => "Import Images",
"Delete_Product" => "Delete Product",
"Edit_Product" => "Edit Product",
"Edit_this_product" => "Edit this product",
"Special_Level" => "Special Level",
"Special_Flag" => "Special Product",
"Delete_Current_Image" => "Delete Current Image (leave the product without any image)",
"Import_Images_Button_Label" => "Import Images",
"Brands_Management" => "Brands Management",
"B_Add_Brand" => "[+B] Add Brand",
"Import_Brands" => "Import Brands",
"Edit_this_brand" => "Edit this brand",
"Brand_reset_for_products" => "The Brand has been reset for all products of that brand",
"Add_Brand" => "Add Brand",
"Colors_Management" => "Colors Management",
"C_Add_Color" => "[+C] Add Color",
"Import_Colors" => "Import Colors",
"Edit_this_color" => "Edit this color",
"Color_reset_for_products" => "The Color has been reset for all products of that color",
"Add_Color" => "Add Color",
"Categories_Management" => "Categories Management",
"Categories_Management_i18n" => "Categories Management - I18N",
"C_Add_Category" => "[+C] Add Category",
"Import_Categories" => "Import categories",
"Edit_this_category" => "Edit this category",
"Add_a_subcategory_under" => "Add a subcategory under",
"All_the_products_and_sub_categories_belonging_to" => "All the products and sub-categories belonging to",
"have_been_reassigned_to_male_plural" => "have been reassigned to",
"IVA_Management" => $IVA . " Management",
"I_Add_IVA" => "[+I] Add " . $IVA . " percentage",
"Import_IVA" => "Import " . $IVA . " percentages",
"Edit_this_IVA" => "Edit this " . $IVA . " percentage",
"Add_IVA" => "Add " . $IVA,
"The_IVA_Percentage" => "The ". $IVA . " percentage",
"IVA_reset_for_products" => "The " . $IVA . " percentage has been reset for all products with that " . $IVA . " percentage",
"Cust_Info" => "Cust. Info",
"Orders_States_Management" => "Orders States Management",
"Delete_this_order" => "Delete this order",
"Edit_this_order" => "Edit this order",
"S_Add_Order_State" => "[+S] Add Order State",
"Import_Orders_States" => "Import Orders States",
"Edit_this_order_state" => "Edit this order state",
"Add_Order_State" => "Add Order State",
"The_Order_State" => "The Order State",
"The_order_state" => "The order state",
"Order_State_reset_for_orders" => "The Order State has been reset for all orders in the named state",
"Add_a_product_under" => "Add a product under",
"currently_its_name_is_male_singular" => "currently its name is",
"currently_its_name_is_female_singular" => "currently its name is",
"currently_its_value_is_female_singular" => "currently its value is",
"Users_Management" => "Users Management",
"Users" => "Users",
"USERS" => "USERS",
"U_Add_User" => "[+U] Add User",
"U_Add_Company_User" => "[+U] Add Company User",
"U_Import_Users" => "Import users",
"Data_handl" => "Data handl.",
"Advert" => "Advert.",
"Reset_password_for" => "Reset password for",
"Change_password_for" => "Change password for",
"Edit_this_user" => "Edit this user",
"Email_this_user" => "Email this user",
"Add_User" => "Add User",
"The_user" => "The user",
"data_have_been_updated" => "data have been updated",
"Privilege" => "Privilege",
"Auth_data_handling_az" => "Auth. data h.",
"Auth_data_handling_pf" => "Auth. pers. data h.",
"Accept_advert_material" => "Accept. advert. mat.",
"Authorization_for_data_handling_az" => "Authorization for data handling",
"Authorization_for_data_handling_pf" => "Authorization for personal data handling",
"Acceptance_of_advertising_material" => "Acceptance of advertising material",
"Our_Notes" => "Our Notes",
"Registration_Date" => "Reg. Date",
"_Import_File" => "File to be Imported",
"End_Import" => "Import Completed.",

));

?>
